@@ -31,12 +31,12 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: irc.c,v 1.113 2004/05/09 15:57:51 f Exp $
+ * $Id: irc.c,v 1.121 2005/04/25 17:20:50 f Exp $
  */
 
-#define IRCII_VERSION	"20040509"	/* YYYYMMDD */
+#define IRCII_VERSION	"20050423"	/* YYYYMMDD */
 /**************************** PATCHED by Flier ******************************/
-#define SCROLLZ_VERSION "1.9.2"
+#define SCROLLZ_VERSION "1.9.5"
 /****************************************************************************/
 
 #include "irc.h"
@@ -265,7 +265,7 @@ char  defban;
 char  bold=2;
 char  *DefaultServer=(char *) 0;
 char  *ScrollZstr=(char *) 0;
-char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (9.5.2004)+Cdcc v" CDCC_VERSION;
+char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (19.12.2004)+Cdcc v" CDCC_VERSION;
 char  *ScrollZver1=(char *) 0;
 #ifdef EXTRA_STUFF
 char  *EString=(char *) 0;
@@ -354,6 +354,11 @@ char  *ChanLogChannels=(char *) 0;
 char  *ChanLogDir=(char *) 0;
 char  *ChanLogPrefix=(char *) 0;
 char  *ChanLogPostfix=(char *) 0;
+char  *ExtTopicDelimiter=(char *) 0;
+#ifdef BLAXTHOS
+char  *OperNick=(char *) 0;
+char  *OperPassword=(char *) 0;
+#endif
 int   DeopPrinted;
 int   KickPrinted;
 int   NickPrinted;
@@ -567,6 +572,11 @@ char VersionInfo[] = {
 #else
     'z',
 #endif
+#ifdef BLAXTHOS
+    'B',
+#else
+    'b',
+#endif
 #ifdef OPER
     ' ',
     'O',
@@ -1556,7 +1566,7 @@ irc_io(prompt, func, my_use_input, loop)
 /**************************** PATCHED by Flier ******************************/
 					/*if (read(screen->fdin, lbuf, 1))*/
 #ifdef SZNCURSES
- 					if (term_read(lbuf,1))
+ 					if (term_read(lbuf, 1))
 #else
  					if (read(screen->fdin, lbuf, 1))
 #endif /* SZNCURSES */
@@ -1589,7 +1599,7 @@ irc_io(prompt, func, my_use_input, loop)
 				/*else if ((n = read(screen->fdin, loc_buffer,
 						BIG_BUFFER_SIZE)) != 0)*/
 #ifdef SZNCURSES
- 				else if ((n=term_read(loc_buffer,BIG_BUFFER_SIZE))!=0)
+ 				else if ((n = term_read(loc_buffer, BIG_BUFFER_SIZE)) != 0)
 #else
 				else if ((n = read(screen->fdin, loc_buffer,
 					      BIG_BUFFER_SIZE)) != 0)
@@ -1665,13 +1675,13 @@ irc_io(prompt, func, my_use_input, loop)
                         CheckTimeMinute();
                         CheckCdccTimers();
                         SetStampFormat(NULL);
-                        if (from_server>=0 && from_server<number_of_servers) {
+                        if (from_server >= 0 && from_server < number_of_servers) {
 #if defined(CELE)
-                            gettimeofday(&PingSent,NULL);
-                            if (PingSent.tv_sec-start_time>30)
+                            gettimeofday(&PingSent, NULL);
+                            if (PingSent.tv_sec - start_time > 30)
 #else
-                                PingSent=time((time_t *) 0);
-                            if (PingSent-start_time>30)
+                                PingSent = time(NULL);
+                            if (PingSent - start_time > 30)
 #endif
                                 send_to_server("PING szlagmeter");
                         }
@@ -1680,12 +1690,12 @@ irc_io(prompt, func, my_use_input, loop)
 /**************************** PATCHED by Flier ******************************/
                 /* update time stamp if necessary */
                 if (Stamp) SetStampFormat(NULL);
-                if (DoOrigNick) {
+                if (DoOrigNick && (time(NULL) >= (LastNick + OrigNickDelay))) {
                     if (OrigNickChange && OrigNick && DoOrigNick) {
-                        char *curnick=get_server_nickname(from_server);
+                        char *curnick = get_server_nickname(from_server);
 
-                        if (curnick && !CheckChannel2(OrigNick,curnick)) SwitchNick();
-                        LastNick=time(NULL);
+                        if (curnick && !CheckChannel2(OrigNick, curnick)) SwitchNick();
+                        LastNick = time(NULL);
                     }
                 }
 /****************************************************************************/
