@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: names.c,v 1.52 2004/01/03 18:07:03 f Exp $
+ * $Id: names.c,v 1.57 2005/01/14 20:13:30 f Exp $
  */
 
 #include "irc.h"
@@ -74,6 +74,7 @@ extern Window *FindWindowByPtr _((Window *));
 extern void UpdateChanLogFName _((ChannelList *));
 extern void ChannelLogReport _((char *, ChannelList *));
 extern void ChannelLogSave _((char *, ChannelList *));
+extern int  RateLimitJoin _((int));
 
 extern NickList *tabnickcompl;
 /****************************************************************************/
@@ -133,7 +134,10 @@ same_channel(channel, chan2)
 	size_t	len, len2;
 
 	/* take the easy way out */
-	if (*channel->channel != '!' && *chan2 != '!')
+/**************************** PATCHED by Flier ******************************/
+	/*if (*channel->channel != '!' && *chan2 != '!')*/
+	if (*channel->channel != '!' || *chan2 != '!')
+/****************************************************************************/
 		return (!my_stricmp(channel->channel, chan2));
 
 	/*
@@ -306,6 +310,7 @@ add_channel(channel, server, connected, copy, key, nowho)
 /**************************** PATCHED by Flier ******************************/
                 new->status = 0;
                 new->gotbans = 0;
+                new->repeatexceptions = 0;
                 new->gotwho = nowho;
 		new->mode = 0;
 		new->limit = 0;
@@ -488,6 +493,9 @@ ChannelList *add_to_channel(channel, nick, server, oper, halfop, voice, userhost
                         ischop = 1;
                         nick++;
                     }
+                    else if (*tmpnick == '&' || *tmpnick == '~') {
+                        nick++;
+                    }
                     tmpnick++;
                 }
                 if (ishalfop && !my_stricmp(nick, get_server_nickname(server)))
@@ -1394,7 +1402,8 @@ char    *servmodes;
                 /* we handle e properly together with b above */
 /****************************************************************************/
  		case 'I':
- 		case 'O': /* this is a weird special case */
+ 		case 'O':
+ 		case 'R': /* this is a weird special case */
 /**************************** Patched by Flier ******************************/
   			/*(void) next_arg(rest, &rest);*/
   			arg = next_arg(rest, &rest);
@@ -1404,10 +1413,10 @@ char    *servmodes;
                         }
 /****************************************************************************/
   			break;
-		case 'R':
+/**************************** PATCHED by Flier ******************************/
+		/*case 'R':
 			value = MODE_REGONLY;
-			break;
-/**************************** Patched by Flier ******************************/
+			break;*/
                 case 'S':
                         value = MODE_SSLONLY;
                         break;
@@ -1511,7 +1520,7 @@ char    *servmodes;
             if (!chan->gotbans || !chan->gotwho) gotops = 0;
             if (!isitme && minusban && HAS_OPS(*chop) && chan->gotbans && chan->gotwho && !gotops && chan->BKList)
                 CheckPermBans(chan);
-            if (!isitme && gotops && (chan->FriendList || chan->BKList))
+            if (!isitme && gotops)
                 HandleGotOps(mynick, chan);
             if (chan->CompressModes) {
                 *compmodeadd = '\0';
@@ -2081,24 +2090,50 @@ reconnect_all_channels(server)
 	ChannelList *tmp = (ChannelList *) 0;
 	char	*mode, *chan;
 /**************************** PATCHED by Flier ******************************/
-	ChannelList *next;
+	ChannelList *next, *tmpchan, *newchan;
 /****************************************************************************/
 
 /**************************** PATCHED by Flier ******************************/
         /*for (tmp = server_list[server].chan_list; tmp; tmp = tmp->next)*/
-        for (tmp = server_list[server].chan_list;tmp;tmp=next)
+        for (tmp = server_list[server].chan_list; tmp; tmp = next)
 /****************************************************************************/
 	{
 /**************************** PATCHED by Flier ******************************/
-                next=tmp->next;
+                next = tmp->next;
 /****************************************************************************/
 		mode = recreate_mode(tmp);
 		chan = tmp->channel;
+/**************************** PATCHED by Flier ******************************/
+                if (RateLimitJoin(server) && tmp != server_list[server].chan_list) {
+                    newchan = (ChannelList *) new_malloc(sizeof(ChannelList));
+                    newchan->channel = (char *) 0;
+                    newchan->key = (char *) 0;
+                    newchan->s_mode = (char *) 0;
+                    newchan->topicstr = (char *) 0;
+                    malloc_strcpy(&newchan->channel, tmp->channel);
+                    malloc_strcpy(&newchan->key, tmp->key);
+                    malloc_strcpy(&newchan->s_mode, empty_string);
+                    malloc_strcpy(&newchan->topicstr, "JOIN");
+                    newchan->status = 0;
+                    newchan->connected = 0;
+                    newchan->next = NULL;
+                    for (tmpchan = server_list[from_server].ChanPendingList;
+                            tmpchan && tmpchan->next; ) {
+                        tmpchan = tmpchan->next;
+                    }
+                    if (tmpchan) tmpchan->next = newchan;
+                    else server_list[from_server].ChanPendingList = newchan;
+                }
+                else {
+/****************************************************************************/
 		if (get_server_version(server) >= Server2_8)
 			send_to_server("JOIN %s%s%s", tmp->channel, tmp->key ? " " : "", tmp->key ? tmp->key : "");
 		else
 			send_to_server("JOIN %s%s%s", tmp->channel, mode ? " " : "", mode ? mode : "");
 		tmp->connected = CHAN_JOINING;
+/**************************** PATCHED by Flier ******************************/
+                }
+/****************************************************************************/
 	}
 }
 
